==> jc-1.4.0.tar.gz: javax/security/auth/login/AppConfigurationEntry.h <==
// public class javax.security.auth.login.AppConfigurationEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e8eeda4264642f60 javax_security_auth_login_AppConfigurationEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_AppConfigurationEntry_H_
#define _JC_javax_security_auth_login_AppConfigurationEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs	_jc_javax_security_auth_login_AppConfigurationEntry$sub_refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$refs	_jc_javax_security_auth_login_AppConfigurationEntry$refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry$nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$object	_jc_javax_security_auth_login_AppConfigurationEntry$object;

typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vmethods	_jc_javax_security_auth_login_AppConfigurationEntry$vmethods;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vtable	_jc_javax_security_auth_login_AppConfigurationEntry$vtable;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vtype	_jc_javax_security_auth_login_AppConfigurationEntry$vtype;

// Constructors
extern void _jc_javax_security_auth_login_AppConfigurationEntry$method$_init$58f28b52c84d9a41(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getControlFlag$f0224413d49273fd(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getLoginModuleName$328f26fc24a38124(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);
extern struct _jc_object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getOptions$d5d50fe667d58325(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getControlFlag$f0224413d49273fd;
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getLoginModuleName$328f26fc24a38124;
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getOptions$d5d50fe667d58325;

// Virtual methods structure
struct _jc_javax_security_auth_login_AppConfigurationEntry$vmethods {
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*(*getControlFlag$f0224413d49273fd)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);
	struct _jc_java_lang_String$object	*(*getLoginModuleName$328f26fc24a38124)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);
	struct _jc_object	*(*getOptions$d5d50fe667d58325)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *);
};

// Vtable
struct _jc_javax_security_auth_login_AppConfigurationEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_AppConfigurationEntry$vmethods	javax_security_auth_login_AppConfigurationEntry;
};

// Vtype
struct _jc_javax_security_auth_login_AppConfigurationEntry$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AppConfigurationEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs {
	struct _jc_java_lang_String$object	*loginModuleName;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*controlFlag;
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry$refs {
    _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs	javax_security_auth_login_AppConfigurationEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs	javax_security_auth_login_AppConfigurationEntry;
};

// Object instance structure
struct _jc_javax_security_auth_login_AppConfigurationEntry$object {
	_jc_javax_security_auth_login_AppConfigurationEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AppConfigurationEntry$vtype	*vtype;
	_jc_javax_security_auth_login_AppConfigurationEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AppConfigurationEntry$vtype _jc_javax_security_auth_login_AppConfigurationEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AppConfigurationEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AppConfigurationEntry$class_object;

#endif	/* _JC_javax_security_auth_login_AppConfigurationEntry_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/AppConfigurationEntry.h <==
// public class javax.security.auth.login.AppConfigurationEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e8eeda4264642f60 javax_security_auth_login_AppConfigurationEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_AppConfigurationEntry_H_
#define _JC_javax_security_auth_login_AppConfigurationEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs	_jc_javax_security_auth_login_AppConfigurationEntry$sub_refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$refs	_jc_javax_security_auth_login_AppConfigurationEntry$refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry$nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry$object	_jc_javax_security_auth_login_AppConfigurationEntry$object;

typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vmethods	_jc_javax_security_auth_login_AppConfigurationEntry$vmethods;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vtable	_jc_javax_security_auth_login_AppConfigurationEntry$vtable;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry$vtype	_jc_javax_security_auth_login_AppConfigurationEntry$vtype;

// Constructors
extern void _jc_javax_security_auth_login_AppConfigurationEntry$method$_init$58f28b52c84d9a41(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getControlFlag$f0224413d49273fd(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getLoginModuleName$328f26fc24a38124(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_auth_login_AppConfigurationEntry$method$getOptions$d5d50fe667d58325(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getControlFlag$f0224413d49273fd;
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getLoginModuleName$328f26fc24a38124;
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry$method_info$getOptions$d5d50fe667d58325;

// Virtual methods structure
struct _jc_javax_security_auth_login_AppConfigurationEntry$vmethods {
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*(*getControlFlag$f0224413d49273fd)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getLoginModuleName$328f26fc24a38124)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOptions$d5d50fe667d58325)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_login_AppConfigurationEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_AppConfigurationEntry$vmethods	javax_security_auth_login_AppConfigurationEntry;
};

// Vtype
struct _jc_javax_security_auth_login_AppConfigurationEntry$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AppConfigurationEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs {
	struct _jc_java_lang_String$object	*loginModuleName;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*controlFlag;
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry$refs {
    _jc_javax_security_auth_login_AppConfigurationEntry$sub_refs	javax_security_auth_login_AppConfigurationEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_AppConfigurationEntry$sub_nonrefs	javax_security_auth_login_AppConfigurationEntry;
};

// Object instance structure
struct _jc_javax_security_auth_login_AppConfigurationEntry$object {
	_jc_javax_security_auth_login_AppConfigurationEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AppConfigurationEntry$vtype	*vtype;
	_jc_javax_security_auth_login_AppConfigurationEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AppConfigurationEntry$vtype _jc_javax_security_auth_login_AppConfigurationEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AppConfigurationEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AppConfigurationEntry$class_object;

#endif	/* _JC_javax_security_auth_login_AppConfigurationEntry_H_ */
